src/Engine.hh
changeset 409 1a03ff151abc
parent 408 e6cfc44266af
child 411 106aaf6eadfe
--- a/src/Engine.hh	Tue Jan 20 23:30:18 2009 +0200
+++ b/src/Engine.hh	Wed Jan 21 00:21:42 2009 +0200
@@ -21,7 +21,7 @@
         GameState *game_state;
 
         /** Set if setupGraphics has been called */
-        const GraphicsConfiguration *graphics_config;
+        const GraphicsConfig *graphics_config;
         
         // Graphics/Input
         Graphics *graphics;
@@ -43,21 +43,34 @@
 
         /**
          * Setup game world using the given terrain, returning the new GameState
+         *
+         * XXX: fix to return void
          */
         GameState& setupGame (Terrain *terrain);
 
         /**
          * Setup default game world using constants from Config.hh
          */
-        GameState& setupGame (void);
+        void setupGame (const TerrainConfig &config);
 
-        // setup graphics
-        void setupGraphics (const GraphicsConfiguration &config);
+        /**
+         * Enable graphics
+         */
+        void setupGraphics (const GraphicsConfig &config);
         
-        // set up network server/client
-        // setting up both of these will lead to odd behaviour :)
+        /**
+         * Setup server, must call setupGame first
+         */
         void setupNetworkServer (const std::string &listen_port);
+
+        /**
+         * Setup client, do *not* call setupGame, configuration comes from the server
+         */
         void setupNetworkClient (const std::string &connect_host, const std::string &connect_port);
+
+        /**
+         * Setup singleplayer, must call setupGame first
+         */
 		void setupSinglePlayer (void);
         
         /**
@@ -43,21 +43,34 @@
 
         /**
-         * Setup default game world using constants from Config.hh
+         * Setup game world using given terrain configuration
          */